@@ -8,16 +8,16 @@ from flask import (Flask, Response, render_template, request,
 from flask_cors import CORS
 from ratelimit import limits, sleep_and_retry
 
-from tuneout.services import Services
+from tuneout.service import Service
 
 app = Flask(__name__, template_folder='docs')
-app.services = Services()
+app.service = Service()
 CORS(app)
 
 _CALLS = 100
 _PERIOD = 60
 
-webbrowser.open('http://127.0.0.1:5000', new=2)
+# webbrowser.open('http://127.0.0.1:5000', new=2)
 
 
 @app.route("/")
@@ -34,8 +34,14 @@ def music():
     if ('domain' and 'url') not in request.json.keys():
         return Response(status=400)
 
-    response = app.services.get(request.json['domain'], request.json['url'])
-    return response
+    data = app.service.extract(request.json['domain'], request.json['url'])
+    
+    if 'Error' in data.keys():
+        return data
+    
+    links = app.service.construct(data)
+    data['links'] = links
+    return data
 # Assets
 
 
